from setuptools import setup

setup(name='manim-tools',
      version='0.1',
      description='An extending command line tool for the manim package',
      url='http://github.com/r14r/manim+',
      author='Ralph Göstenmeier',
      author_email='r14r@via-internet.de',
      license='MIT',
      packages=['manim-tools'],
      zip_safe=False)
    